@@ -27,18 +27,14 @@ build_time_vars = {'ABIFLAGS': '',
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
            '-fstack-protector-strong -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+           '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+           '-mfpu=neon -O3 -pipe -fstack-protector-strong -fno-plt '
+           '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
+           '-Werror=format-security         -fstack-clash-protection '
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
            '-fstack-protector-strong -fno-plt -fexceptions         '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-           '-fstack-protector-strong -fno-plt -fexceptions         '
-           '-Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         '
-           '-fstack-clash-protection -g '
-           '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+           '-fstack-clash-protection',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -47,9 +43,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                      '-fstack-protector-strong -fno-plt -fexceptions         '
                      '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                     '-Werror=format-security         -fstack-clash-protection '
-                     '-g '
-                     '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+                     '-Werror=format-security         -fstack-clash-protection',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -66,15 +60,14 @@ build_time_vars = {'ABIFLAGS': '',
                 '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                 '-fstack-protector-strong -fno-plt -fexceptions         '
                 '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-                '-Werror=format-security         -fstack-clash-protection -g '
-                "-ffile-prefix-map=/build/python/src=/usr/src/debug/python' "
+                "-Werror=format-security         -fstack-clash-protection' "
                 "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.10.9/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.10.9/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.10.10/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.10.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
@@ -674,22 +667,18 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
-                             '-pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-clash-protection -march=armv7-a '
+                             '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                             '-fstack-protector-strong -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -g '
-                             '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                             '-std=c99 -Wextra -Wno-unused-result '
-                             '-Wno-unused-parameter '
+                             '-fstack-clash-protection -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
@@ -698,18 +687,15 @@ build_time_vars = {'ABIFLAGS': '',
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-Werror=format-security         -fstack-clash-protection '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
+              '-Werror=format-security         -fstack-clash-protection '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
               '-fstack-protector-strong -fno-plt -fexceptions         '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
-              '-Werror=format-security         -fstack-clash-protection -g '
-              '-ffile-prefix-map=/build/python/src=/usr/src/debug/python',
+              '-Werror=format-security         -fstack-clash-protection',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
@@ -720,20 +706,14 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fstack-protector-strong -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-g '
-                   '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -753,22 +733,19 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -pipe -fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-clash-protection -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                        '-fstack-clash-protection -march=armv7-a '
+                        '-mfloat-abi=hard -mfpu=neon -O3 -pipe '
                         '-fstack-protector-strong -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -g '
-                        '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                        '-std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-fstack-clash-protection -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -780,7 +757,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -822,9 +799,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-ltk8.6 -ltkstub8.6 -ltcl8.6 -ltclstub8.6',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.9 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.10.10 ./python '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -852,8 +829,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.10.9',
- 'abs_srcdir': '/build/python/src/Python-3.10.9',
+ 'abs_builddir': '/build/python/src/Python-3.10.10',
+ 'abs_srcdir': '/build/python/src/Python-3.10.10',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
